package com.jjt.calc.service;

import java.util.Date;
import java.util.List;
import com.jjt.calc.domain.TwinCalcHourSpec;

/**
 * 按配方1小时统计数据Service接口
 *
 * @author wukai
 * @date 2025-01-18
 */
public interface ITwinCalcHourSpecService {
    /**
     * 查询按配方1小时统计数据
     *
     * @param id 按配方1小时统计数据主键
     * @return 按配方1小时统计数据
     */
    public TwinCalcHourSpec selectTwinCalcHourSpecById(Long id);

    /**
     * 查询按配方1小时统计数据列表
     *
     * @param twinCalcHourSpec 按配方1小时统计数据
     * @return 按配方1小时统计数据集合
     */
    public List<TwinCalcHourSpec> selectTwinCalcHourSpecList(TwinCalcHourSpec twinCalcHourSpec);

    /**
     * 新增按配方1小时统计数据
     *
     * @param twinCalcHourSpec 按配方1小时统计数据
     * @return 结果
     */
    public int insertTwinCalcHourSpec(TwinCalcHourSpec twinCalcHourSpec);

    /**
     * 修改按配方1小时统计数据
     *
     * @param twinCalcHourSpec 按配方1小时统计数据
     * @return 结果
     */
    public int updateTwinCalcHourSpec(TwinCalcHourSpec twinCalcHourSpec);

    /**
     * 批量删除按配方1小时统计数据
     *
     * @param ids 需要删除的按配方1小时统计数据主键集合
     * @return 结果
     */
    public int deleteTwinCalcHourSpecByIds(Long[] ids);

    /**
     * 删除按配方1小时统计数据信息
     *
     * @param id 按配方1小时统计数据主键
     * @return 结果
     */
    public int deleteTwinCalcHourSpecById(Long id);
    /**
     * 根据日期获取统计数据
     *
     * @param date 日期
     * @return 结果
     */
    List<TwinCalcHourSpec> selectTwinCalcHourSpecListByDate(Date date);
}
